nbxmpp.smacks.Smacks

Package nbxmpp :: Module smacks :: Class Smacks |
[hide private]
[frames] | no frames]

# Class Smacks

source code

This is Smacks is the Stream Management class. It takes care of requesting and sending acks. Also, it keeps track of the unhandled outgoing stanzas.

The dispatcher has to be able to access this class to increment the number of handled stanzas

Instance Methods | [hide private]
__init__(self, con) | source code
set_owner(self, owner) | source code
_neg_response(self, disp, stanza) | source code
negociate(self, resume=True) | source code
resume_request(self) | source code
send_ack(self, disp, stanza) | source code
request_ack(self) | source code
check_ack(self, disp, stanza) Checks if the number of stanzas sent are the same as the number of stanzas received by the server. Pops stanzas that were handled by the server from the queue. | source code
error_handling(self, disp, stanza) | source code

Method Details | [hide private]

### __init__(self, con) (Constructor) | source code

### set_owner(self, owner) | source code

### _neg_response(self, disp, stanza) | source code

### negociate(self, resume=True) | source code

### resume_request(self) | source code

### send_ack(self, disp, stanza) | source code

### request_ack(self) | source code

### check_ack(self, disp, stanza) | source code
Checks if the number of stanzas sent are the same as the number of stanzas received by the server. Pops stanzas that were handled by the server from the queue.

### error_handling(self, disp, stanza) | source code